@@ -35,9 +35,8 @@ from websockets.exceptions import ConnectionClosedOK, ConnectionClosedError
 
 from .utils import Repr
 from .utils.convertors import Convertor
-from .ext import telemetry as telemetry_extension
-from .config import apiUrl, heartbeatInterval, topPublicRoomsInterval
 from .entities import Client, User, Room, UserPreview, Message, BaseUser, Context
+from .config import apiUrl, heartbeatInterval, topPublicRoomsInterval, telemetryInterval
 from .utils.parsers import parse_sentence_to_tokens as parse_message, parse_word_to_token as parse_word
 from .exceptions import NoConnectionException, InvalidAccessToken, InvalidSize, NotEnoughArguments, CommandNotFound, MemberNotFound, CommandAlreadyDefined
 
@@ -99,7 +98,7 @@ def command(func: Awaitable = None, *, name: str = None, cooldown: int = 0, alia
 class DogeClient(Client):
     """Represents your Dogehouse client."""
 
-    def __init__(self, token: str, refresh_token: str, *, room: str = None, muted: bool = False, reconnect_voice: bool = False, prefix: Union[str, List[str]] = "!", telemetry: bool = False):
+    def __init__(self, token: str, refresh_token: str, *, room: str = None, muted: bool = False, reconnect_voice: bool = False, prefix: Union[str, List[str]] = "!", telemetry = None):
         """
         Initialize your Dogehouse client
 
@@ -110,7 +109,7 @@ class DogeClient(Client):
             muted (bool, optional): Wether or not the client should be muted. Defaults to False.
             reconnect_voice (bool, optional): When the client disconnects from the voice server, should it try to reconnect. Defaults to False.
             prefix (List of strings or a string, optional): The bot prefix.
-            telemetry (bool, optional): Whether or not you want to enable telemetry for your bot. Defaults to False.
+            telemetry (telemetry class, optional): The telemetry class that will be used. Defaults to None.
         """
         super().__init__(None, room, [], prefix)
 
@@ -126,10 +125,10 @@ class DogeClient(Client):
         self.__waiting_for = {}
         self.__waiting_for_fetches = {}
         self.__command_cooldown_cache = {}
-        self.telemetry_enabled = telemetry
+        self.telemetry = telemetry
         
         if telemetry:
-            asyncio.ensure_future(telemetry_extension.start())
+            asyncio.ensure_future(telemetry.start())
 
     async def __fetch(self, op: str, data: dict):
         fetch = str(uuid4())
@@ -303,8 +302,6 @@ class DogeClient(Client):
         async def heartbeat():
             debug("Dogehouse: Starting heartbeat")
             while self.__active:
-                if self.telemetry_enabled:
-                    await telemetry_extension.transmit(self)
                 await self.__socket.send("ping")
                 await asyncio.sleep(heartbeatInterval)
 
@@ -314,6 +311,12 @@ class DogeClient(Client):
                 await self.get_top_public_rooms()
                 await asyncio.sleep(topPublicRoomsInterval)
 
+        async def perform_telemetry():
+            debug(f"Dogehouse: {'Starting to perform telemetry' if self.telemetry else 'Passing telemetry, as its disabled'}")
+            while self.telemetry and self.__active:
+                await self.telemetry.transmit(self)
+                await asyncio.sleep(telemetryInterval)
+
         try:
             info("Dogehouse: Connecting with Dogehouse websocket")
             async with websockets.connect(apiUrl) as ws:
@@ -334,9 +337,11 @@ class DogeClient(Client):
 
                 event_loop_task = loop.create_task(event_loop())
                 get_top_rooms_task = loop.create_task(get_top_rooms_loop())
+                perform_telemetry_task = loop.create_task(perform_telemetry())
                 await heartbeat()
                 await event_loop_task()
                 await get_top_rooms_task()
+                await perform_telemetry_task()
         except ConnectionClosedOK:
             info("Dogehouse: Websocket connection closed peacefully")
             self.__active = False
